@@ -35,6 +35,7 @@
 #include <QSplashScreen>
 #include <QPixmap>
 #include "maemobarcodewindow.h"
+#include "common.h"
 
 
 // remove me before release, only used for debugging
@@ -43,20 +44,20 @@ QTime debugSpeedTimer;
 
 int main(int argc, char *argv[])
 {
+    qDebug() << DEBUGINFO << "Started mbarcode";
     QApplication a(argc, argv);
-    qDebug() << "main(): Started mbarcode";
 
     debugSpeedTimer.start();
 
-    //qDebug() << "main(): Showing splash";
+    //qDebug() << DEBUGINFO << "Showing splash";
     QPixmap pixmap(":/images/splash.png");
     QSplashScreen splash(pixmap);
     splash.show();
-    qDebug() << "main(): Showed splash, t=" << debugSpeedTimer.elapsed();
+    qDebug() << DEBUGINFO << "Showed splash, t=" << debugSpeedTimer.elapsed();
 
     a.processEvents();
 
-    qDebug() << "main(): Showing window";
+    qDebug() << DEBUGINFO << "Showing window";
     MaemoBarcodeWindow w;
 
     if (!QDBusConnection::sessionBus().isConnected()) {
@@ -77,7 +78,7 @@ int main(int argc, char *argv[])
         exit(3);
     }
 
-    qDebug() << "main(): Setup DBus connections, t=" << debugSpeedTimer.elapsed();
+    qDebug() << DEBUGINFO << "Setup DBus connections, t=" << debugSpeedTimer.elapsed();
 
     if(w.settings->value("use_full_screen", true).toBool()) {
         w.showFullScreen(); // showFullScreen increases performance drastically using openGL - loses menus though...
