@@ -6,15 +6,20 @@
 #include <QPluginLoader>
 #include <QDir>
 
+class ResultsWindow;
+
 class PluginLoaderThread : public QThread
 {
     Q_OBJECT
 public:
-    PluginLoaderThread(MaemoBarcodeWindow *resultsWindow);
+    PluginLoaderThread(MaemoBarcodeWindow *mainWindow);
     void run();
 
 private:
     MaemoBarcodeWindow *w;
+
+private slots:
+    void loadPlugins();
 };
 
 
