@@ -52,20 +52,13 @@ ResultsWindow::ResultsWindow(MaemoBarcodeWindow *parent) :
 {
     ui->setupUi(this);
     this->parent = parent;
-    checkTimer = new QTimer(this);
-    connect(checkTimer, SIGNAL(timeout()),this,SLOT(checkPlugins()));
+
     setAttribute(Qt::WA_Maemo5StackedWindow);
     ui->tblResults->setItemDelegate(new PluginActionListDelegate(this));
     ui->tblResults->horizontalHeader()->setResizeMode(QHeaderView::Stretch);
 
     selectionTimer = new QTimer(this);
     connect(selectionTimer, SIGNAL(timeout()), this, SLOT(selectionTimerExpiry()));
-
-
-    //hideMeTimer = new QTimer(this);
-    //connect(hideMeTimer, SIGNAL(timeout()), this, SLOT(hideMeTimerExpiry()));
-
-    //checkPlugins(); // call it here to avoid the initial wait
 }
 
 ResultsWindow::~ResultsWindow()
@@ -76,9 +69,14 @@ ResultsWindow::~ResultsWindow()
 void ResultsWindow::setPluginActions(QList<PluginAction *>plugins) {
     qDebug() << "ResultsWindow::setPluginActions(): Called.";
     this->plugins = plugins;
-    //foreach(PluginAction *p, plugins){
-    //    qDebug() << "ResultsWindow::plugin item = " << p->getName();
-    //}
+
+    foreach(PluginAction* plugin, plugins) {
+        // skip plugins that are not enabled
+        if(plugin->getEnabled()) {
+            qDebug() << "ResultsWindow::setPluginActions(): Checking action plugin " << plugin->getName();
+            connect(plugin, SIGNAL(isReady()), this, SLOT(pluginReady()));
+        }
+    }
 
 }
 void ResultsWindow::changeEvent(QEvent *e)
@@ -100,47 +98,29 @@ void ResultsWindow::processBarcode(QString barcode) {
         ui->lblResults->setText(tr("Results for '%1'").arg(barcode).simplified());
     }
 
-    PluginUpdateCounter = 0;
+    pluginUpdateCounter = 0;
     //hideMeTimer->stop();
 
     addedPlugins.clear(); // clear the plugins from the list
 
     // save the barcode text
     this->barcode_text = QString(barcode);
-    checkTimer->start(1000); // check for updated plugins every x milliseconds
-
-    checkPlugins(); // move to here so that if we want to auto-run the first plugin, the timer isn't started after we disable it!
 
 }
 
-
-
-// This API is not ideal as it results in our continuing to check plugins when they may have already decided they don't want to be used
-// it would probably be better IMO to have two functions isReady() and isInterested()
-// Once a plugin has decided it's not interested in the payload we can exclude it from the checking list (save time/power)
-// and eventually we'll know whether all the plugins have become ready or not
-// in the meantime, I'll limit the plugin checkin with a timer.
-
-void ResultsWindow::checkPlugins() {
-//    qDebug() << "Checking plugins";
+void ResultsWindow::pluginReady() {
+    qDebug() << "ResultsWindow::pluginReady(): Called";
     bool addedNewPlugins=false;
 
-    PluginUpdateCounter++;
-
-    foreach(PluginAction* plugin, plugins) {
-        // skip plugins that are not enabled
-        if(!plugin->getEnabled())
-            continue;
-
-        qDebug() << "Checking action plugin " << plugin->getName() << "is ready" << plugin->isReady();
-        if(plugin->getEnabled() && plugin->isReady() && !addedPlugins.contains(plugin)) { // check if it's ready and that it has not yet been added
-            addedNewPlugins=true;
-            addedPlugins.append(plugin); // add it to the list of added plugins, so we don't add it twice
-            qDebug() << "Added plugin" << plugin->getText() << plugin->getName();
+    PluginAction* pluginAction = (PluginAction*)sender(); // find the plugin that sent the signal
+    if(pluginAction) { // make sure the cast went ok
+        if(!addedPlugins.contains(pluginAction)) { // don't add the plugin more than once
+            addedPlugins.append(pluginAction);
+            addedNewPlugins = true;
+            pluginUpdateCounter++;
         }
     }
 
-
     if(addedNewPlugins==true){
         QAbstractItemModel *oldModel = ui->tblResults->model();
         PluginActionListModel *model = new PluginActionListModel(this, addedPlugins);
@@ -152,7 +132,7 @@ void ResultsWindow::checkPlugins() {
 
     if(addedPlugins.length()>0  && parent->AutoUseFirstPlugin){ // && this->parent->NumEnabledPlugins==1
         qDebug() << "AutoUseFirstPlugin, running this one";
-        checkTimer->stop(); // no point in continuing to check for plugins
+
         QMaemo5InformationBox::information (this->parent, addedPlugins.at(0)->getName() + " run", 1000);
         addedPlugins.at(0)->clickAction(this); // run the plugin
         //hideMeTimer->singleShot(1500, this, SLOT(hideMeTimerExpiry()));
@@ -162,9 +142,6 @@ void ResultsWindow::checkPlugins() {
         this->parent->videoWidget->start(false);
     }
 
-    if(PluginUpdateCounter > PLUGIN_COUNT_LIMIT)
-        checkTimer->stop();
-
 
 }
 
@@ -174,6 +151,8 @@ void ResultsWindow::on_pushButton_clicked()
 }
 
 QSize PluginActionListDelegate::sizeHint(const QStyleOptionViewItem &option, const QModelIndex &index) {
+    Q_UNUSED(index)
+    Q_UNUSED(option)
     return QSize();
 }
 
