@@ -88,21 +88,20 @@ private:
     QList<PluginAction*> addedPlugins;
 
     Ui::ResultsWindow *ui;
-    QTimer *checkTimer;
 
     QString barcode_text;
 
     QTimer *selectionTimer;
     //QTimer *hideMeTimer; // needed to allow the results window to show otherwise it goes mad when we try to autorun a plugin
 
-    int PluginUpdateCounter;
+    int pluginUpdateCounter;
     MaemoBarcodeWindow *parent;
 
 private slots:
     void on_tblResults_clicked(QModelIndex index);
     void on_pushButton_clicked();
-    void checkPlugins(); // called by a timer to see if there are any plugins which are ready
     void selectionTimerExpiry();
+    void pluginReady();
 //    void hideMeTimerExpiry(); // needed to allow the results window to show otherwise it goes mad when we try to autorun a plugin
 };
 
